@@ -1,4 +1,4 @@
-#!perl
+#!/usr/bin/env perl
 package MyPackage;
 use Moose;
 use lib '../../../../../lib';
@@ -8,13 +8,13 @@ sub set_error{}
 sub get_log_space{}
 	
 sub my_method{
-	my ( $self, $cell ) = @_;
-	my ($column, $row ) = $self->parse_column_row( $cell );
-	print $self->error if( !defined $column or !defined $row );
-	return ($column, $row );
+    my ( $self, $cell ) = @_;
+    my ($column, $row ) = $self->parse_column_row( $cell );
+    print $self->error if( !defined $column or !defined $row );
+    return ($column, $row );
 }
 
 package main;
 
-my $parser = MyPackage->new( count_from_zero => 0 );
+my $parser = MyPackage->new;
 print '(' . join( ', ', $parser->my_method( 'B2' ) ) . ")\n";
\ No newline at end of file
